unit MakeLossy;

interface

procedure makeLossySampleBlock(var sampleBlockCh0: array of LongInt; var sampleBlockCh1: array of LongInt; samplesCount: integer);
                                                            // Transforms sampleBlockCh0 and sampleBlockCh1 (in case of stereo)
                                                            // into a lossy version by setting the 5 LSBs to zero.
                                                            // First sample transformed is in element with index 0.
                                                            // Last sample transformed is in element with index samplesCount - 1.

implementation
uses
  wavIO;

function lossySample(sample: LongInt): LongInt; // 16 bit samples only
var
 s: LongInt;
 begin
   if sample >= 0 then
      lossySample := sample AND $0000FFE0  // 5 LSBs set to 0
   else
      begin
      s := sample + $10000;  // sample's bit representation interpreted as a positive number
      s := s AND $0000FFE0; // 5 LSBs set to 0
      lossySample := s - $10000; // interpret it back as a negative number;
      end;
 end;

procedure makeLossySampleBlock(var sampleBlockCh0: array of LongInt; var sampleBlockCh1: array of LongInt; samplesCount: integer);
var
 i: integer;
 begin
    if channelCount() = 1 then
      for i:= 0 to samplesCount -1 do
          sampleBlockCh0[i] := lossySample(sampleBlockCh0[i])
    else // stereo:
      for i:= 0 to samplesCount -1 do
          begin
          sampleBlockCh0[i] := lossySample(sampleBlockCh0[i]);
          sampleBlockCh1[i] := lossySample(sampleBlockCh1[i]);
          end;
 end;

end.
